@@ -21,14 +21,11 @@
  *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *     General Public License for more details.
  *
- *     You should have received a copy of the GNU General
- *     Public License along with this program; if not,
- *     write to the Free Software Foundation, Inc., 59 Temple
- *     Place - Suite 330, Boston, MA  02111, USA.
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program; if not, write to the Free Software Foundation,
+ *     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,, USA.
  */
 
-/* $Id: helpers.c,v 1.3 2000/05/01 09:31:06 roland Exp $ */
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -99,10 +96,11 @@ void safe_realloc (void **p, size_t siz)
   *p = r;
 }
 
-void safe_free (void **p)
-{
+void safe_free (void *ptr)
+{ 
+  void **p = (void **)ptr;
   if (*p)
-  {
+  { 
     free (*p);
     *p = 0;
   }
@@ -120,3 +118,51 @@ char *safe_strdup (const char *s)
   return (p);
 }
 
+size_t safe_strlen(const char *a)
+{
+  return a ? strlen (a) : 0;
+}
+
+int safe_strcmp(const char *a, const char *b)
+{
+  return strcmp(NONULL(a), NONULL(b));
+}
+
+
+static inline int ascii_isupper (int c)
+{
+  return (c >= 'A') && (c <= 'Z');
+}
+
+static inline int ascii_tolower (int c)
+{
+  if (ascii_isupper (c))
+    return c | 32;
+
+  return c;
+}
+
+int ascii_strcasecmp (const char *a, const char *b)
+{
+  int i;
+
+  if (a == b)
+    return 0;
+  if (a == NULL && b)
+    return -1;
+  if (b == NULL && a)
+    return 1;
+
+  for (;; a++, b++)
+  {
+    if ((i = ascii_tolower (*a) - ascii_tolower (*b)))
+      return i;
+    /* test for NUL here rather that in the for loop in order to detect unqual
+     * length strings (see http://dev.mutt.org/trac/ticket/3601)
+     */
+    if (!*a)
+      break;
+  }
+
+  return 0;
+}
