@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2005  Roland Rosenfeld <roland@spinnaker.de>
+ *  Copyright (C) 2000-2018  Roland Rosenfeld <roland@spinnaker.de>
  *
  *  This program is free software; you can redistribute
  *  it and/or modify it under the terms of the GNU
@@ -19,17 +19,23 @@
  *
  */
 
-/* $Id: qpto8bit.c,v 1.3 2005-10-29 14:48:11 roland Exp $ */
-
 #include <stdio.h>
 
 #include "helpers.h"
 #include "rfc822.h"
 #include "rfc2047.h"
 
-int main ()
+int main (int argc, char * argv[])
 {
   char buff[2048];
+#ifdef HAVE_ICONV
+  const char **charsetptr = &Charset;
+#endif
+
+#ifdef HAVE_ICONV
+  if (argc > 1)
+    *charsetptr = argv[1];
+#endif
 
   while (fgets (buff, sizeof (buff), stdin)) {
     rfc2047_decode (buff, buff, sizeof (buff));
